@@ -31,11 +31,23 @@ struct res_entry {
 
 struct glob_res {
     NMEM nmem;
+    unsigned flags;
     size_t number_of_entries;
     struct res_entry **last_entry;
     struct res_entry *entries;
 };
 
+static void add_entry(yaz_glob_res_t res, const char *str)
+{
+    struct res_entry *ent =
+        nmem_malloc(res->nmem, sizeof(*ent));
+    ent->file = nmem_strdup(res->nmem, str);
+    ent->next = 0;
+    *res->last_entry = ent;
+    res->last_entry = &ent->next;
+    res->number_of_entries++;
+}
+
 static void glob_r(yaz_glob_res_t res, const char *pattern, size_t off,
                    char *prefix)
 {
@@ -57,6 +69,12 @@ static void glob_r(yaz_glob_res_t res, const char *pattern, size_t off,
         glob_r(res, pattern, i, prefix);
         prefix[prefix_len] = '\0';
     }
+    else if ((res->flags & YAZ_FILE_GLOB_FAIL_NOTEXIST) &&
+             !is_pattern && !pattern[i])
+    {
+        strcpy(prefix + prefix_len, pattern + off);
+        add_entry(res, prefix);
+    }
     else
     {
         DIR * dir = opendir(*prefix ? prefix : "." );
@@ -82,13 +100,7 @@ static void glob_r(yaz_glob_res_t res, const char *pattern, size_t off,
                     }
                     else
                     {
-                        struct res_entry *ent =
-                            nmem_malloc(res->nmem, sizeof(*ent));
-                        ent->file = nmem_strdup(res->nmem, prefix);
-                        ent->next = 0;
-                        *res->last_entry = ent;
-                        res->last_entry = &ent->next;
-                        res->number_of_entries++;
+                        add_entry(res, prefix);
                     }
                     prefix[prefix_len] = '\0';
                 }
@@ -127,12 +139,18 @@ static void sort_them(yaz_glob_res_t res)
 }
 
 int yaz_file_glob(const char *pattern, yaz_glob_res_t *res)
+{
+    return yaz_file_glob2(pattern, res, 0);
+}
+
+int yaz_file_glob2(const char *pattern, yaz_glob_res_t *res, unsigned flags)
 {
     char prefix[FILENAME_MAX+1];
     NMEM nmem = nmem_create();
 
     *prefix = '\0';
     *res = nmem_malloc(nmem, sizeof(**res));
+    (*res)->flags = flags;
     (*res)->number_of_entries = 0;
     (*res)->nmem = nmem;
     (*res)->entries = 0;
